/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core;

import java.util.Collection;

/**
 *
 * CapabilityContainer is a an interface that defines the capability aggregation 
 * methods of {@linkplain Resource Resource}.
 *
 * @author Dan Jemiolo (danj)
 *
 */

interface CapabilityContainer
{
    /**
     * 
     * Registers the given capability instance with the resource.
     * 
     * @param capability
     *
     */
    void addCapability(Capability capability);
    
    /**
     * 
     * @param capabilityURI
     * 
     * @return The Capability associated with the given URI, or null if 
     *         no such capability exists.
     *
     */
    Capability getCapability(String capabilityURI);
    
    /**
     * 
     * @return The URIs of all of the capabilities added to the resource.
     *
     */
    Collection getCapabilityURIs();
    
    /**
     * 
     * @param capabilityURI
     * 
     * @return True, if getCapability(String) returns a non-null value.
     *
     */
    boolean hasCapability(String capabilityURI);
}
