/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core;

import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 * 
 * InitializationFailure is a set of operations for components that have 
 * an initialization phase with distinct failure state.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface InitializationFailure
{
    /**
     * 
     * @return True if the component's initialization routine was started 
     *         but failed to run to completion successfully.
     *
     */
    boolean hasFailedToInitialize();
    
    /**
     * 
     * @return The exception that was created at the time the initialization 
     *         routine failed, or null if initialization was successful.
     *
     */
    SoapFault getCauseOfFailure();
}
