/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.descriptor;

import java.util.Map;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 * 
 * InitParamDescriptor defines a sub-section of the Muse deployment descriptor 
 * that may be used in multiple places - the sequence of initialization 
 * parameters. This mini-descriptor can be used to load the name-value pairs 
 * found in <em>init-param</em> elements and read them as a java.util.Map.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public interface InitParamDescriptor extends XmlSerializable
{
    Map getInitializationParameters();
    
    /**
     * 
     * @param elementContainingInitParams
     *        The element that contains zero or more child elements named 
     *        <em>init-param</em>, <strong>not</strong> the <em>init-param</em> 
     *        element(s) itself.
     *
     */
    void load(Element elementContainingInitParams)
        throws SoapFault;
    
    void setInitializationParameters(Map parameters);
}
