/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.descriptor;

import java.io.File;
import java.io.IOException;
import java.util.logging.ConsoleHandler;
import java.util.logging.FileHandler;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.logging.SimpleFormatter;

/**
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class LoggingConfig
{
    public static final String MUSE_LOGGER_NAME = "org.apache.muse.core";
    
    private File _logFile = null;
    
    private Level _logLevel = null;
    
    protected Handler createLogHandler(File logFile)
    {   
        Handler handler = null;
        
        try
        {
            handler = new FileHandler(logFile.getAbsolutePath());
        }
        
        catch (IOException error)
        {
            //
            // what can we do? redirect errors to stderr/console
            //
            error.printStackTrace();
            handler = new ConsoleHandler();
        }
        
        handler.setFormatter(new SimpleFormatter());        
        return handler;
    }
    
    public File getLogFile()
    {
        return _logFile;
    }
    
    public Level getLogLevel()
    {
        return _logLevel;
    }
    
    public Logger newInstance()
    {
        File logFile = getLogFile();
        Level logLevel = getLogLevel();
        
        File logDir = logFile.getParentFile();
        logDir.mkdirs();
        
        Logger log = Logger.getLogger(MUSE_LOGGER_NAME);
        log.setLevel(logLevel);
        
        Handler handler = createLogHandler(logFile);
        log.addHandler(handler);
        
        return log;
    }
    
    public void setLogFile(File logFile)
    {
        _logFile = logFile;
    }
    
    public void setLogLevel(Level logLevel)
    {
        _logLevel = logLevel;
    }
}
