/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.descriptor;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;

/**
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public class SimpleInitParamDescriptor implements InitParamDescriptor
{
    private Map _parameters = null;
    
    protected Map createInitializationParameters(Element xml)
    {
        Map parameters = new HashMap();
        
        Element[] paramXML = XmlUtils.getElements(xml, DescriptorConstants.INIT_PARAM_QNAME);
        
        for (int n = 0; n < paramXML.length; ++n)
        {
            String name = XmlUtils.getElementText(paramXML[n], DescriptorConstants.PARAM_NAME_QNAME);
            String value = XmlUtils.getElementText(paramXML[n], DescriptorConstants.PARAM_VALUE_QNAME);
            parameters.put(name, value);
        }
        
        return parameters;
    }
    
    public Map getInitializationParameters()
    {
        return _parameters;
    }

    public void load(Element elementContainingInitParams)
    {
        _parameters = createInitializationParameters(elementContainingInitParams);
    }

    public void setInitializationParameters(Map parameters)
    {
        _parameters = parameters;
    }

    public Element toXML()
    {
        return toXML(XmlUtils.createDocument());
    }

    public Element toXML(Document doc)
    {
        //
        // HACK: Just like the load() method, which takes an element that 
        //       contains init-param elements, we have to create a dummy 
        //       root element to contain our real init-params. This should 
        //       be discarded by the consumer. It's the only way to do this 
        //       and be in compliance with XmlSerializable.toXML().
        //
        Element root = XmlUtils.createElement(doc, DescriptorConstants.INIT_PARAM_QNAME);
        
        Map parameters = getInitializationParameters();
        Iterator i = parameters.keySet().iterator();
        
        while (i.hasNext())
        {
            Object name = i.next();
            Object value = parameters.get(name);
            
            Element param = XmlUtils.createElement(doc, DescriptorConstants.INIT_PARAM_QNAME);
            XmlUtils.setElement(param, DescriptorConstants.PARAM_NAME_QNAME, name);
            XmlUtils.setElement(param, DescriptorConstants.PARAM_VALUE_QNAME, value);
            
            root.appendChild(param);
        }
        
        return root;
    }
}
