/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.routing;

import javax.xml.namespace.QName;

import org.apache.muse.ws.addressing.WsaConstants;

/**
 * 
 * This ResourceIdFactory creates IDs of the form "MuseResource-<em>N</em>", 
 * where <em>N</em> is a monotonically increasing integer greater than zero.
 * The QName of the identifier is specified in WsaUtils.DEFAULT_RESOURCE_ID_QNAME.
 * 
 * @author Dan Jemiolo (danj)
 *
 */

public class CounterResourceIdFactory implements ResourceIdFactory
{
    private static final String _DEFAULT_NAME = "MuseResource";
    
    private int _count = 1;
    
    private String _counterPrefix = null;
    
    public CounterResourceIdFactory()
    {
        this(_DEFAULT_NAME);
    }
    
    public CounterResourceIdFactory(String counterPrefix)
    {
        _counterPrefix = counterPrefix;
    }
    
    /**
     * 
     * @return The value defined by WsaUtils.DEFAULT_RESOURCE_ID_QNAME
     * 
     */
    public QName getIdentifierName()
    {
        return WsaConstants.DEFAULT_RESOURCE_ID_QNAME;
    }
    
    /**
     * 
     * @return The string value "MuseResource-N", where N is the number of 
     *         times this method has been called (starting with 1).
     *         
     */
    public String getNextIdentifier()
    {
        return _counterPrefix + '-' + _count++;
    }
    
    /**
     * method to set the identifier count. needed
     * for persistency.
     */
    public void setIdentifierCount(int c)
    {
    	if (c > this._count) this._count = c; 
    }
}
