/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.serializer;

import java.text.ParseException;
import java.util.Date;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;
import org.apache.muse.ws.addressing.soap.SoapFault;

/**
 *
 * DateSerializer transforms java.util.Date to XML and back. It is expected 
 * that the date values will be in the XSD dateTime format.
 *
 * @author Dan Jemiolo (danj)
 * 
 * @see XmlUtils#getDate(Element)
 *
 */

public class DateSerializer implements Serializer
{
    public Object fromXML(Element xml)
        throws SoapFault
    {
        try
        {
            return XmlUtils.getDate(xml);
        }
        
        catch (ParseException error)
        {
            throw new SoapFault(error.getMessage(), error);
        }
    }
    
    public Class getSerializableType()
    {
        return Date.class;
    }
    
    public Element toXML(Object obj, QName qname)
    {
        return XmlUtils.createElement(qname, obj);
    }
}
