/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.serializer;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.xml.XmlUtils;

/**
 *
 * ElementSerializer performs no transformation on its data - it exists to 
 * allow users to create method signatures that process raw XML. Users who 
 * include an Element in a method's parameter list will receive the n-th 
 * Element found in the request's SOAP Body.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class ElementSerializer implements Serializer
{
    public Object fromXML(Element xml)
    {
        return xml;
    }
    
    public Class getSerializableType()
    {
        return Element.class;
    }
    
    public Element toXML(Object obj, QName qname)
    {
        if (obj == null)
            return XmlUtils.createElement(qname);
        
        return XmlUtils.createElement(XmlUtils.createDocument(), qname, obj);
    }
}
