/* 
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.muse.core.serializer;

import javax.xml.namespace.QName;

import org.w3c.dom.Element;

import org.apache.muse.util.messages.Messages;
import org.apache.muse.util.messages.MessagesFactory;
import org.apache.muse.util.xml.XmlSerializable;
import org.apache.muse.util.xml.XmlUtils;

/**
 *
 * XmlSerializableSerializer performs no transformation on its data - it 
 * simply casts objects to instances of XmlSerializable and calls their 
 * toXML() method to perform serialization. This class does <b>not</b> 
 * support the fromXML method, as there is no way for it to know what 
 * concrete class to use in order to instantiate the XML into POJO form. 
 * It is merely a way to serialize XmlSerializable objects into SOAP/XML 
 * without having to write custom serializers for those types.
 *
 * @author Dan Jemiolo (danj)
 *
 */

public class XmlSerializableSerializer implements Serializer
{
    //
    // Used to lookup all exception messages
    //
    private static Messages _MESSAGES = MessagesFactory.get(XmlSerializableSerializer.class);
    
    public Object fromXML(Element xml)
    {
        throw new UnsupportedOperationException(_MESSAGES.get("NoFromXML"));
    }
    
    public Class getSerializableType()
    {
        return XmlSerializable.class;
    }
    
    public Element toXML(Object obj, QName qname)
    {
        if (obj == null)
            return XmlUtils.createElement(qname);
        
        Element xml = ((XmlSerializable)obj).toXML();
        return XmlUtils.createElement(XmlUtils.createDocument(), qname, xml);
    }
}
